@@ -167,6 +167,10 @@ recover_data = function(object, ...) {
 #'   can be helpful because it provides a modicum of security against the
 #'   possibility that the original data used when fitting the model has been
 #'   altered or removed.
+#' @param pwts Optional vector of prior weights. Typically, this may be obtained
+#'   from the fitted \code{model} via \code{weights(model)}. If this is provided,
+#'   it is used to set weights as long as it is non-\code{NULL} and the same length 
+#'   as the number of rows of the data.
 #' @param addl.vars Character value or vector specifying additional predictors
 #'   to include in the reference grid. These must be names of variables that
 #'   exist, or you will get an error. 
@@ -174,15 +178,17 @@ recover_data = function(object, ...) {
 #'   additional computations later on that depend on these variables; e.g., 
 #'   bias adjustments for random slopes of variables not among the fixed predictors.
 #' 
-#' @method recover_data call
+#' @exportS3Method recover_data call
 #' @export
 #' @order 2
 recover_data.call = function(object, trms, na.action, data = NULL, 
-                             params = "pi", frame, addl.vars, ...) {
+                             params = "pi", frame, pwts, addl.vars, ...) {
     fcall = object # because I'm easily confused
     vars = setdiff(.all.vars(trms), params)
-    if(!missing(addl.vars))
-        vars = union(vars, addl.vars)
+    if(missing(addl.vars))
+        addl.vars = character(0)
+    vars = union(vars, addl.vars)
+        
     .offset. = NULL
     if (!missing(frame)) {
         .offset. = model.offset(frame)
@@ -251,10 +257,18 @@ recover_data.call = function(object, trms, na.action, data = NULL,
         tbl = tbl[complete.cases(tbl), , drop=FALSE]
     }
     
+    if(!missing(pwts) && !is.null(pwts)) {
+        if (length(pwts) == nrow(tbl))
+            tbl[["(weights)"]] = pwts
+        else
+            warning("Model has ", length(pwts), " prior weights, but we recovered ",
+                    nrow(tbl), " rows of data.\nSo prior weights were ignored.",
+                    call. = FALSE)
+    }
+    
     if(!is.null(.offset.) && !all(.offset. == 0)) {
         tbl[[".offset."]] = .offset.
-        addl.vars = if(!missing(addl.vars)) c(addl.vars, ".offset.")
-                    else                    ".offset."
+        addl.vars = c(addl.vars, ".offset.")
     }
     
     attr(tbl, "call") = object # the original call
@@ -404,11 +418,13 @@ emm_basis = function(object, trms, xlev, grid, ...) {
 # Then caller can use try() to check for other types of errors,
 # and just print this message otherwise 
 # NOT @exported
+#' @exportS3Method recover_data default
 recover_data.default = function(object, ...) {
     paste("Can't handle an object of class ", dQuote(class(object)[1]), "\n",
           paste(.show_supported(), collapse=""))
 }
 # NOT @exported
+#' @exportS3Method emm_basis default      
 emm_basis.default = function(object, trms, xlev, grid, ...) {
     stop("Can't handle an object of class", dQuote(class(object)[1]), "\n",
          .show_supported())
