@@ -21,6 +21,14 @@
 
 ### This file has summary.emmGrid S3 method and related functions
 
+# as.data.frame for a summary just passes thru
+# This creates an infinite loop if we're not careful with using `as.data.frame`
+# to coerce a summary_emm object to a regular data frame.
+#' @export
+as.data.frame.summary_emm = function(x, ...) {
+    attr(x, "digits") = getOption("digits")
+    x
+}
 
 # S3 summary method
 
@@ -46,7 +54,7 @@
 #' non-estimable. It is permissible for the rows of \code{linfct} to be linearly
 #' dependent, as long as \code{null == 0}, in which case a reduced set of 
 #' contrasts is tested. Linear dependence and nonzero \code{null} cause an 
-#' error. The returned object has an aditional \code{"est.fcns"} attribute, which
+#' error. The returned object has an additional \code{"est.fcns"} attribute, which
 #' is a list of the linear functions associated with the joint test.
 #'
 #' @param object An object of class \code{"emmGrid"} (see \link{emmGrid-class})
@@ -105,12 +113,13 @@
 #'   or \code{FALSE}, the object is passed to \code{\link{hpd.summary}}. Otherwise, 
 #'   a logical value of \code{TRUE} will have it return a frequentist summary.
 #' @param bias.adjust Logical value for whether to adjust for bias in
-#'   back-transforming (\code{type = "response"}). This requires a value of 
+#'   back-transforming (\code{type = "response"}). This requires a valid value of 
 #'   \code{sigma} to exist in the object or be specified.
 #' @param sigma Error SD assumed for bias correction (when 
 #'   \code{type = "response"} and a transformation
 #'   is in effect), or for constructing prediction intervals. If not specified,
-#'   \code{object@misc$sigma} is used, and an error is thrown if it is not found.
+#'   \code{object@misc$sigma} is used, and a warning is issued if it is not found
+#'   or not valid.
 #'   \emph{Note:} \code{sigma} may be a vector, but be careful that it correctly
 #'   corresponds (perhaps after recycling) to the order of the reference grid.
 #' @param ... Optional arguments such as \code{scheffe.rank} 
@@ -147,12 +156,22 @@
 #'   Similarly, confidence intervals are computed on the linear-predictor scale,
 #'   then inverse-transformed.
 #'   
+#' @section Bias adjustment when back-transforming:
 #'   When \code{bias.adjust} is \code{TRUE}, then back-transformed estimates
 #'   are adjusted by adding 
 #'   \eqn{0.5 h''(u)\sigma^2}, where \eqn{h} is the inverse transformation and
 #'   \eqn{u} is the linear predictor. This is based on a second-order Taylor
 #'   expansion. There are better or exact adjustments for certain specific
 #'   cases, and these may be incorporated in future updates.
+#'   
+#'   Note: In certain models, e.g., those with non-gaussian families,
+#'   \code{sigma} is initialized as \code{NA}, and so by default, bias adjustment
+#'   is skipped and a warning is issued. You may override this by specifying a
+#'   value for \code{sigma}. However, \emph{with ordinary generalized linear models,
+#'   bias adjustment is inappropriate} and you should not try to do it. With GEEs and GLMMs,
+#'   you probably should \emph{not} use \code{sigma(model)}, and instead you should create an
+#'   appropriate value using the estimated random effects, e.g., from \code{VarCorr(model)}.
+#'   An example is provided in the \dQuote{transformations} vignette.
 #' 
 #' @section P-value adjustments:
 #'   The \code{adjust} argument specifies a multiplicity adjustment for tests or
@@ -528,8 +547,10 @@ summary.emmGrid <- function(object, infer, level, adjust, by,
         inv = FALSE
         link = NULL
     }
-    if(inv && bias.adjust && !is.null(link)) 
+    if(inv && bias.adjust && !is.null(link)) {
         link = .make.bias.adj.link(link, sigma)
+        bias.adjust = attr(link, "bias.adjust")  # disables later message if skipped
+    }
     
     # et = 1 if a prediction, 2 if a contrast (or unmatched or NULL), 3 if pairs
     et = pmatch(c(misc$estType, "c"), c("prediction", "contrast", "pairs"), nomatch = 2)[1]
@@ -714,7 +735,9 @@ summary.emmGrid <- function(object, infer, level, adjust, by,
 #' @param interval Type of interval desired (partial matching is allowed): 
 #' \code{"none"} for no intervals,
 #'   otherwise confidence or prediction intervals with given arguments, 
-#'   via \code{\link{confint.emmGrid}}.
+#'   via \code{\link{confint.emmGrid}}. 
+#'   Note: prediction intervals are not available
+#'   unless the model family is \code{"gaussian"}.
 #'   
 #' @export
 #' @return \code{predict} returns a vector of predictions for each row of \code{object@grid}.
@@ -733,8 +756,11 @@ predict.emmGrid <- function(object, type,
 
     interval = match.arg(interval)
     if (interval %in% c( "confidence", "prediction")) {
-        if (interval == "prediction")
-            object@misc$.predFlag = TRUE
+        if (interval == "prediction") {
+            ok = object@misc$.predFlag = .chk.predict(object)
+            if (!ok)
+                return(NULL)
+        }
         return(confint.emmGrid(object, type = type, level = level, 
                                bias.adjust = bias.adjust, sigma = sigma, ...))
     }
@@ -774,7 +800,11 @@ predict.emmGrid <- function(object, type,
 #' @param destroy.annotations Logical value. If \code{FALSE}, an object of class
 #'   \code{summary_emm} is returned (which inherits from \code{data.frame}),
 #'   but if displayed, details like confidence levels, P-value adjustments, 
-#'   transformations, etc. are also shown.
+#'   transformations, etc. are also shown. But unlike the result
+#'   of \code{summary}, the number of digits displayed
+#'   is obtained from \code{getOption("digits")} rather than using the
+#'   optimal digits algorithm we usually use. Thus, it is formatted more like a 
+#'   regular data frame, but with any annotations and groupings still intact.
 #'   If \code{TRUE} (not recommended), a \dQuote{plain vanilla} data frame is 
 #'   returned, based on \code{row.names} and \code{check.names}.
 #' @param row.names passed to \code{\link{as.data.frame}}
@@ -787,9 +817,10 @@ predict.emmGrid <- function(object, type,
 as.data.frame.emmGrid = function(x, 
                                  row.names = NULL, optional, check.names = TRUE, 
                                  destroy.annotations = FALSE, ...) {
-    rtn = summary(x, ...)
+    rtn = summary.emmGrid(x, ...)
+    attr(rtn, "digits") = getOption("digits")
     if(destroy.annotations)
-        rtn = as.data.frame(rtn, row.names = row.names, check.names = check.names)
+        rtn = as.data.frame.data.frame(rtn, row.names = row.names, check.names = check.names)
     rtn
 }
 
@@ -804,7 +835,7 @@ as.data.frame.emmGrid = function(x,
 #' @export
 "[.summary_emm" = function(x, ..., as.df = FALSE) {
     attr(x, "by.vars") = NULL
-    rtn = as.data.frame(x)[...]
+    rtn = as.data.frame.data.frame(x)[...]
     if ((!as.df) && (!is.null(attr(rtn, "estName"))))
         class(rtn) = c("summary_emm", "data.frame")
     rtn
@@ -911,9 +942,16 @@ as.data.frame.emmGrid = function(x,
 # patch-in alternative back-transform stuff for bias adjustment
 # Currently, we just use a 2nd-order approx for everybody:
 #   E(h(nu + E))  ~=  h(nu) + 0.5*h"(nu)*var(E)
+# We also return an attribute "bias.adjust" which is TRUE if ok, FALSE if we aborted
 .make.bias.adj.link = function(link, sigma) {
-    if (is.null(sigma))
-        stop("Must specify 'sigma' to obtain bias-adjusted back transformations", call. = FALSE)
+    ###if (is.null(sigma) || (!is.null(sigma) && (is.na(sigma) || (sigma < 0)))) { ###old code
+    if(is.null(sigma) || (length(sigma) == 0) || is.na(sigma[1]) || (sigma[1] < 0)) {
+         warning("Bias adjustment skipped: No valid 'sigma' provided\n", 
+                "(And perhaps bias.adjust should NOT be used; see ? summary.emmGrid)", 
+                call. = FALSE)
+        attr(link, "bias.adjust") = FALSE
+        return(link)
+    }
     link$inv = link$linkinv
     link$der = link$mu.eta
     link$sigma22 = sigma^2 / 2
@@ -921,6 +959,7 @@ as.data.frame.emmGrid = function(x,
     link$linkinv = function(eta) with(link, inv(eta) + sigma22 * der2(eta))
     link$mu.eta = function(eta) with(link, der(eta) +
                                          1000 * sigma22 * (der2(eta + .0005) - der2(eta - .0005)))
+    attr(link, "bias.adjust") = TRUE
     link
 }
 ####!!!!! TODO: Re-think whether we are handling Scheffe adjustments correctly
@@ -1264,6 +1303,9 @@ print.summary_emm = function(x, ..., digits=NULL, quote=FALSE, right=TRUE, expor
     if (is.null(estn)) # uh-oh, somebody messed it up - so Hail Mary
         return(invisible(print(data.frame(x))))
     
+    if(!is.null(attr(x, "digits")))
+        digits = attr(x, "digits")
+    
     test.stat.names = c("t.ratio", "z.ratio", "F.ratio", "T.square")  # format these w 3 dec places
     x.save = x
     if(export) x.save = list()
